@@ -11,8 +11,7 @@ import (
 	libvirtclient "github.com/openshift/cluster-api-provider-libvirt/pkg/cloud/libvirt/client"
 	mocklibvirt "github.com/openshift/cluster-api-provider-libvirt/pkg/cloud/libvirt/client/mock"
 	fakeclusterclientset "github.com/openshift/cluster-api-provider-libvirt/test"
-	clusterv1beta1 "github.com/openshift/cluster-api/pkg/apis/cluster/v1alpha1"
-	machinev1beta1 "github.com/openshift/cluster-api/pkg/apis/machine/v1beta1"
+	machinev1beta1 "github.com/openshift/machine-api-operator/pkg/apis/machine/v1beta1"
 	kubernetesfake "k8s.io/client-go/kubernetes/fake"
 
 	"k8s.io/client-go/kubernetes/scheme"
@@ -40,8 +39,6 @@ func TestMachineEvents(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	cluster := stubCluster()
-
 	machineInvalidProviderConfig := machine.DeepCopy()
 	machineInvalidProviderConfig.Spec.ProviderSpec.Value = nil
 
@@ -49,7 +46,7 @@ func TestMachineEvents(t *testing.T) {
 		name               string
 		machine            *machinev1beta1.Machine
 		error              string
-		operation          func(actuator *Actuator, cluster *clusterv1beta1.Cluster, machine *machinev1beta1.Machine)
+		operation          func(actuator *Actuator, machine *machinev1beta1.Machine)
 		event              string
 		createVolumeErr    error
 		deleteVolumeErr    error
@@ -63,8 +60,8 @@ func TestMachineEvents(t *testing.T) {
 		{
 			name:    "Create machine event failed (invalid configuration)",
 			machine: machineInvalidProviderConfig,
-			operation: func(actuator *Actuator, cluster *clusterv1beta1.Cluster, machine *machinev1beta1.Machine) {
-				actuator.Create(context.TODO(), cluster, machine)
+			operation: func(actuator *Actuator, machine *machinev1beta1.Machine) {
+				actuator.Create(context.TODO(), machine)
 			},
 			event: "Warning FailedCreate InvalidConfiguration",
 		},
@@ -72,8 +69,8 @@ func TestMachineEvents(t *testing.T) {
 			name:    "Create machine event failed (error creating libvirt client)",
 			machine: machine,
 			error:   libvirtClientError,
-			operation: func(actuator *Actuator, cluster *clusterv1beta1.Cluster, machine *machinev1beta1.Machine) {
-				actuator.Create(context.TODO(), cluster, machine)
+			operation: func(actuator *Actuator, machine *machinev1beta1.Machine) {
+				actuator.Create(context.TODO(), machine)
 			},
 			event: "Warning FailedCreate CreateError",
 		},
@@ -81,8 +78,8 @@ func TestMachineEvents(t *testing.T) {
 			name:            "Create machine event failed (error creating volume)",
 			machine:         machine,
 			createVolumeErr: fmt.Errorf("error"),
-			operation: func(actuator *Actuator, cluster *clusterv1beta1.Cluster, machine *machinev1beta1.Machine) {
-				actuator.Create(context.TODO(), cluster, machine)
+			operation: func(actuator *Actuator, machine *machinev1beta1.Machine) {
+				actuator.Create(context.TODO(), machine)
 			},
 			event: "Warning FailedCreate CreateError",
 		},
@@ -90,8 +87,8 @@ func TestMachineEvents(t *testing.T) {
 			name:            "Create machine event failed (error creating domain)",
 			machine:         machine,
 			createDomainErr: fmt.Errorf("error"),
-			operation: func(actuator *Actuator, cluster *clusterv1beta1.Cluster, machine *machinev1beta1.Machine) {
-				actuator.Create(context.TODO(), cluster, machine)
+			operation: func(actuator *Actuator, machine *machinev1beta1.Machine) {
+				actuator.Create(context.TODO(), machine)
 			},
 			event: "Warning FailedCreate CreateError",
 		},
@@ -99,24 +96,24 @@ func TestMachineEvents(t *testing.T) {
 			name:            "Create machine event failed (error looking up domain)",
 			machine:         machine,
 			lookupDomainErr: fmt.Errorf("error"),
-			operation: func(actuator *Actuator, cluster *clusterv1beta1.Cluster, machine *machinev1beta1.Machine) {
-				actuator.Create(context.TODO(), cluster, machine)
+			operation: func(actuator *Actuator, machine *machinev1beta1.Machine) {
+				actuator.Create(context.TODO(), machine)
 			},
 			event: "Warning FailedCreate CreateError",
 		},
 		{
 			name:    "Create machine event succeed",
 			machine: machine,
-			operation: func(actuator *Actuator, cluster *clusterv1beta1.Cluster, machine *machinev1beta1.Machine) {
-				actuator.Create(context.TODO(), cluster, machine)
+			operation: func(actuator *Actuator, machine *machinev1beta1.Machine) {
+				actuator.Create(context.TODO(), machine)
 			},
 			event: "Normal Created Created Machine libvirt-actuator-testing-machine",
 		},
 		{
 			name:    "Delete machine event failed (invalid configuration)",
 			machine: machineInvalidProviderConfig,
-			operation: func(actuator *Actuator, cluster *clusterv1beta1.Cluster, machine *machinev1beta1.Machine) {
-				actuator.Delete(context.TODO(), cluster, machine)
+			operation: func(actuator *Actuator, machine *machinev1beta1.Machine) {
+				actuator.Delete(context.TODO(), machine)
 			},
 			event: "Warning FailedDelete InvalidConfiguration",
 		},
@@ -124,8 +121,8 @@ func TestMachineEvents(t *testing.T) {
 			name:    "Delete machine event failed (error creating libvirt client)",
 			machine: machine,
 			error:   libvirtClientError,
-			operation: func(actuator *Actuator, cluster *clusterv1beta1.Cluster, machine *machinev1beta1.Machine) {
-				actuator.Delete(context.TODO(), cluster, machine)
+			operation: func(actuator *Actuator, machine *machinev1beta1.Machine) {
+				actuator.Delete(context.TODO(), machine)
 			},
 			event: "Warning FailedDelete DeleteError",
 		},
@@ -133,8 +130,8 @@ func TestMachineEvents(t *testing.T) {
 			name:            "Delete machine event failed (error getting domain)",
 			machine:         machine,
 			domainExistsErr: fmt.Errorf("error"),
-			operation: func(actuator *Actuator, cluster *clusterv1beta1.Cluster, machine *machinev1beta1.Machine) {
-				actuator.Delete(context.TODO(), cluster, machine)
+			operation: func(actuator *Actuator, machine *machinev1beta1.Machine) {
+				actuator.Delete(context.TODO(), machine)
 			},
 			event: "Warning FailedDelete DeleteError",
 		},
@@ -143,8 +140,8 @@ func TestMachineEvents(t *testing.T) {
 			machine:         machine,
 			domainExists:    true,
 			deleteDomainErr: fmt.Errorf("error"),
-			operation: func(actuator *Actuator, cluster *clusterv1beta1.Cluster, machine *machinev1beta1.Machine) {
-				actuator.Delete(context.TODO(), cluster, machine)
+			operation: func(actuator *Actuator, machine *machinev1beta1.Machine) {
+				actuator.Delete(context.TODO(), machine)
 			},
 			event: "Warning FailedDelete DeleteError",
 		},
@@ -153,8 +150,8 @@ func TestMachineEvents(t *testing.T) {
 			machine:         machine,
 			domainExists:    true,
 			deleteVolumeErr: fmt.Errorf("error"),
-			operation: func(actuator *Actuator, cluster *clusterv1beta1.Cluster, machine *machinev1beta1.Machine) {
-				actuator.Delete(context.TODO(), cluster, machine)
+			operation: func(actuator *Actuator, machine *machinev1beta1.Machine) {
+				actuator.Delete(context.TODO(), machine)
 			},
 			event: "Warning FailedDelete DeleteError",
 		},
@@ -162,8 +159,8 @@ func TestMachineEvents(t *testing.T) {
 			name:         "Delete machine event succeeds",
 			machine:      machine,
 			domainExists: true,
-			operation: func(actuator *Actuator, cluster *clusterv1beta1.Cluster, machine *machinev1beta1.Machine) {
-				actuator.Delete(context.TODO(), cluster, machine)
+			operation: func(actuator *Actuator, machine *machinev1beta1.Machine) {
+				actuator.Delete(context.TODO(), machine)
 			},
 			event: "Normal Deleted Deleted Machine libvirt-actuator-testing-machine",
 		},
@@ -207,7 +204,7 @@ func TestMachineEvents(t *testing.T) {
 				t.Fatalf("Could not create AWS machine actuator: %v", err)
 			}
 
-			tc.operation(actuator, cluster, tc.machine)
+			tc.operation(actuator, tc.machine)
 			select {
 			case event := <-eventsChannel:
 				if event != tc.event {
